package com.zskk.dicom.monitor.report;

import org.apache.commons.mail.EmailException;

import com.zskk.dicom.monitor.config.Configs;
import com.zskk.dicom.monitor.config.Constants;
import com.zskk.dicom.monitor.utils.ExceptionUtil;
import com.zskk.dicom.monitor.utils.MailerUtil;

public class ErrReporterSender implements Runnable {

	/**
	 * 准备上报的异常信息
	 */
	private String errMsg;

	public ErrReporterSender(String errMsg) {
		this.errMsg = errMsg;
		Configs.sysLog.info("error:\n" + errMsg);
	}

	@Override
	public void run() {
		Long curTime = System.currentTimeMillis();
		if ((curTime - Constants.lastErrReportTime.get()) / 1000 < Configs.errReportTimeInterval) {
			// 异常发送间隔太短
			// 暂时放入队列
			if (!ErrReporter.errReportsQueue.contains(errMsg)) {
				ErrReporter.errReportsQueue.add(errMsg);
			}
			return;
		} else {
			ErrReporter.errReportsQueue.add(errMsg);
		}

		if (ErrReporter.errReportsQueue.isEmpty()) {
			return;
		}
		// 保存异常同步的时间
		Constants.lastErrReportTime.set(System.currentTimeMillis());
		// 准备发送邮件
		StringBuilder sb = new StringBuilder();
		for (String msg : ErrReporter.errReportsQueue) {
			sb.append(msg).append("\r\n<br />");
		}
		// 清除队列
		ErrReporter.errReportsQueue.clear();
		try {
			String to = Configs.errReportToEmail;
			String cc = null;
			if (to.contains(";")) {
				// 将to中的多个邮箱，放到cc中
				if (cc == null) {
					cc = to.substring(to.indexOf(";") + 1);
				}
				to = to.substring(0, to.indexOf(";"));
			}
			// 开始邮件发送异常信息
			MailerUtil.SendMail(Configs.errReportFromEmailHost, Configs.errReportFromEmail, Configs.errReportFromEmail, Configs.errReportFromEmailPwd, to, cc, "utf8", Configs.hospitalId + "--" + Configs.errReportTitle, sb.toString(), null);
		} catch (EmailException e) {
			e.printStackTrace();
			Configs.sysLog.info(ExceptionUtil.getExceptionTxt(e));
		}
		sb = null;
	}

}
