package com.zskk.dicom.monitor.uploader;

import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import org.apache.commons.io.FileUtils;

import com.zskk.dicom.monitor.config.Configs;

public class UploadsQueue {

	/**
	 * 待处理的文件队列
	 */
	protected static List<File> fileQueue = Collections.synchronizedList(new ArrayList<File>());

	/**
	 * 文件上传线程池
	 */
	private static ExecutorService pools = Executors.newFixedThreadPool(2);

	public static void add(File file) {
		if (fileQueue.contains(file)) {
			// 文件已经在队列中
			Configs.sysLog.info(file + ", The file is already in the queue!");
		} else {
			fileQueue.add(file);
			Configs.sysLog.info(file + ", The file is added to the queue!");
			pools.execute(new UploadRunner(file));
		}
	}

	/**
	 * 系统启动时，将文件夹中的文件添加到上传队列中
	 */
	@SuppressWarnings("rawtypes")
	public static void init() {
		File dir = new File(Configs.monitorDir);
		StringBuilder sb = new StringBuilder();
		Iterator its = FileUtils.iterateFiles(dir, new String[] { "dcm" }, true);
		while (its.hasNext()) {
			File file = (File) its.next();
			add(file);
			sb.append(file.getAbsolutePath() + "\n");
		}
		if (sb.length() > 0) {
			Configs.sysLog.info("System start & inits, this files added to the queue:\n" + sb.toString());
		}
		sb = null;
	}

}
